Reference
================================================

.. automodule:: tinysoundfont
   :members: Synth, SoundFontException, Sequencer

.. automodule:: tinysoundfont.midi
   :members: load, load_memory, Event, Action, NoteOn, NoteOff, ControlChange, ProgramChange, PitchBend
